@@ -55,6 +55,8 @@ class ConnectionConfig(BaseModel):
     connection_retries: int = 1
     max_attempts: int = 3
     http2: bool = False
+    # a path to a cert file or false to turn off verification
+    verify: Optional[Union[bool, str]] = None
 
 
 class Login(BaseModel):
@@ -149,6 +151,7 @@ class TxnHeaderName(str, Enum):
     SENDER_TOKEN = "txn-sender-token"
     SENDER = "txn-sender"
     VALUE = "txn-value"
+    ACCOUNT = "txn-account"
 
 
 class TxnHeaders(BaseModel):
@@ -160,6 +163,7 @@ class TxnHeaders(BaseModel):
     sender_token: Optional[str] = None
     sender: Optional[str] = None
     value: Optional[str] = None
+    account: Optional[Tuple[Optional[str], str]] = None
 
     def as_headers(self) -> dict:
         headers = {}
@@ -179,6 +183,11 @@ class TxnHeaders(BaseModel):
             headers[TxnHeaderName.SENDER.value] = self.sender
         if self.value:
             headers[TxnHeaderName.VALUE.value] = self.value
+        if self.account:
+            if self.account[0] is not None:
+                headers[TxnHeaderName.ACCOUNT.value] = f"{self.account[0]}:{self.account[1]}"
+            else:
+                headers[TxnHeaderName.ACCOUNT.value] = self.account[1]
         return headers
 
 
