@@ -906,6 +906,7 @@ class Simba(SimbaSync):
         self,
         nickname: Optional[str] = None,
         alias: Optional[str] = None,
+        network: Optional[str] = None,
         login: Login = None,
         config: ConnectionConfig = None,
     ) -> List[dict]:
@@ -916,7 +917,8 @@ class Simba(SimbaSync):
                 params.add_filter(FieldFilter(field="nickname", op=FilterOp.EQ, value=nickname))
             if alias:
                 params.add_filter(FieldFilter(field="alias", op=FilterOp.EQ, value=alias))
-
+            if network:
+                params.add_filter(FieldFilter(field="networks", op=FilterOp.EQ, value=network))
         return await SimbaRequest(
             endpoint=Path.USER_ACCOUNTS,
             query_params=params,
